/**
 *
 */
package com.j711h401.common.util;

import java.sql.Connection;
import java.sql.SQLException;

import org.hibernate.FlushMode;
import org.hibernate.Session;
import org.hibernate.SessionFactory;
import org.hibernate.cfg.Configuration;
import org.hibernate.jdbc.Work;
import org.hibernate.service.ServiceRegistry;
import org.hibernate.service.ServiceRegistryBuilder;

/**
 * @author skalavacharla
 * 
 */
public final class HibernateUtil
{

    private static SessionFactory sessionFactory = null;

    static
    {
        staticInit();
    }

    public static SessionFactory getSessionFactory()
    {
        return sessionFactory;
    }

    private static void staticInit()
    {
        try
        {
        	Configuration configuration = new Configuration();
			configuration.configure();
			ServiceRegistry serviceRegistry = new ServiceRegistryBuilder().applySettings(configuration.getProperties()).buildServiceRegistry();        
			sessionFactory = configuration.buildSessionFactory(serviceRegistry);
        }
        catch (Throwable ex)
        {
            // Make sure you log the exception, as it might be swallowed
            System.err.println("Initial SessionFactory creation failed." + ex);
            ex.printStackTrace();
            throw new ExceptionInInitializerError(ex);
        }
    }

    public static Session getSession()
    {
        Session session = sessionFactory.getCurrentSession();
        session.setFlushMode(FlushMode.MANUAL);

        return session;
    }

    public static void setReadUncommitted(Session session)
    {
        // Setting the TransactionIsolation to TRANSACTION_READ_UNCOMMITTED is
        // the equivalent of adding NOLOCK to the select statements.
        // This is necessary to avoid deadlocks when running multiple threads
        session.doWork(new Work()
        {
            public void execute(Connection connection) throws SQLException
            {
                connection.setTransactionIsolation(Connection.TRANSACTION_READ_UNCOMMITTED);
            }
        });
    }

}